wsipipe.load.datasets package
=============================

.. automodule:: wsipipe.load.datasets
   :members:
   :undoc-members:
   :show-inheritance:

loader module
-----------------------------------

.. automodule:: wsipipe.load.datasets.loader
   :members:
   :undoc-members:
   :show-inheritance:

camelyon16 module
---------------------------------------

.. automodule:: wsipipe.load.datasets.camelyon16
   :members:
   :undoc-members:
   :show-inheritance:

stripai module
------------------------------------

.. automodule:: wsipipe.load.datasets.stripai
   :members:
   :undoc-members:
   :show-inheritance:

registry module
-------------------------------------

.. automodule:: wsipipe.load.datasets.registry
   :members:
   :undoc-members:
   :show-inheritance:

